window.Gleam.initSearch([{"doc":"wisp","title":"wisp","content":"![Wisp](https://github.com/lpil/wisp/blob/main/docs/images/cover.png?raw=true)\n\n[![Package Version](https://img.shields.io/hexpm/v/wisp)](https://hex.pm/packages/wisp)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/wisp/)\n\nWisp is a practical Gleam web framework for rapid development and easy maintenance.\nWe worry about the hassle of web development, and you focus on writing your\napplication.\n\nIt is based around two concepts: handlers and middleware.\n\n# Handlers\n\nA handler is a function that takes a HTTP request and returns a HTTP\nresponse. A handler may also take other arguments, such as a &quot;context&quot; type\ndefined in your application which may hold other state such as a database\nconnection or user session.\n\n```gleam\nimport wisp.{type Request, type Response}\n\npub type Context {\n  Context(secret: String)\n}\n\npub fn handle_request(request: Request, context: Context) -&gt; Response {\n  wisp.ok()\n}\n```\n\n# Middleware\n\nA middleware is a function that takes a response returning function as its\nlast argument, and itself returns a response. As with handlers both\nmiddleware and the functions they take as an argument may take other\narguments.\n\nMiddleware can be applied in a handler with Gleam&#39;s `use` syntax. Here the\n`log_request` middleware is used to log a message for each HTTP request\nhandled, and the `serve_static` middleware is used to serve static files\nsuch as images and CSS.\n\n```gleam\nimport wisp.{type Request, type Response}\n\npub fn handle_request(request: Request) -&gt; Response {\n  use &lt;- wisp.log_request(request)\n  use &lt;- wisp.serve_static(request, under: &quot;/static&quot;, from: &quot;/public&quot;)\n  wisp.ok()\n}\n```\n\n# Learning Wisp\n\nThe Wisp examples are a good place to start. They cover various scenarios and\ninclude comments and tests.\n\n- [Hello, World!](https://github.com/lpil/wisp/tree/main/examples/00-hello-world)\n- [Routing](https://github.com/lpil/wisp/tree/main/examples/01-routing)\n- [Working with form data](https://github.com/lpil/wisp/tree/main/examples/02-working-with-form-data)\n- [Working with JSON](https://github.com/lpil/wisp/tree/main/examples/03-working-with-json)\n- [Working with other formats](https://github.com/lpil/wisp/tree/main/examples/04-working-with-other-formats)\n- [Using a database](https://github.com/lpil/wisp/tree/main/examples/05-using-a-database)\n- [Serving static assets](https://github.com/lpil/wisp/tree/main/examples/06-serving-static-assets)\n- [Logging](https://github.com/lpil/wisp/tree/main/examples/07-logging)\n- [Working with cookies](https://github.com/lpil/wisp/tree/main/examples/08-working-with-cookies)\n- [Configuring default responses](https://github.com/lpil/wisp/tree/main/examples/09-configuring-default-responses)\n- [Working with files](https://github.com/lpil/wisp/tree/main/examples/10-working-with-files)\n\nAPI documentation is available on [HexDocs](https://hexdocs.pm/wisp/).\n\n# Wisp applications\n\nThese open source Wisp applications may be useful examples.\n\n- [https://packages.gleam.run/](https://github.com/gleam-lang/packages): A HTML\n  serving application that uses an SQLite + LiteFS database, deployed to Fly.io.\n","url":"index.html"},{"doc":"wisp","title":"Body","content":"pub type Body {\n  Text(StringTree)\n  Bytes(BytesTree)\n  File(path: String)\n  Empty\n}\n The body of a HTTP response, to be sent to the client.\n\nText(StringTree)\n A body of unicode text.\n\n The body is represented using a `StringTree`. If you have a `String`\n you can use the `string_tree.from_string` function to convert it.\n\n\nBytes(BytesTree)\n A body of binary data.\n\n The body is represented using a `BytesTree`. If you have a `BitArray`\n you can use the `bytes_tree.from_bit_array` function to convert it.\n\n\nFile(path: String)\n A body of the contents of a file.\n\n This will be sent efficiently using the `send_file` function of the\n underlying HTTP server. The file will not be read into memory so it is\n safe to send large files this way.\n\n\nEmpty\n An empty body. This may be returned by the `require_*` middleware\n functions in the event of a failure, invalid request, or other situation\n in which the request cannot be processed.\n\n Your application may wish to use a middleware to provide default responses\n in place of any with an empty body.\n\n\nSynonyms:\nwisp.Body\nwisp Body","url":"wisp.html#Body"},{"doc":"wisp","title":"Connection","content":"pub type Connection =\n  internal.Connection\n The connection to the client for a HTTP request.\n\n The body of the request can be read from this connection using functions\n such as `require_multipart_body`.\n\n\nSynonyms:\nwisp.Connection\nwisp Connection","url":"wisp.html#Connection"},{"doc":"wisp","title":"FormData","content":"pub type FormData {\n  FormData(\n    values: List(#(String, String)),\n    files: List(#(String, UploadedFile)),\n  )\n}\n Data parsed from form sent in a request&#39;s body.\n\nFormData(\n  values: List(#(String, String)),\n  files: List(#(String, UploadedFile)),\n)\n\nvalues\n&lt;p&gt;String values of the form’s fields.&lt;/p&gt;\n\nfiles\n&lt;p&gt;Uploaded files.&lt;/p&gt;\n\nSynonyms:\nwisp.FormData\nwisp FormData","url":"wisp.html#FormData"},{"doc":"wisp","title":"LogLevel","content":"pub type LogLevel {\n  EmergencyLevel\n  AlertLevel\n  CriticalLevel\n  ErrorLevel\n  WarningLevel\n  NoticeLevel\n  InfoLevel\n  DebugLevel\n}\n Type to set the log level of the Erlang&#39;s logger\n\n See the [Erlang logger documentation][1] for more information.\n\n [1]: https://www.erlang.org/doc/man/logger\n\nEmergencyLevel\n\n\nAlertLevel\n\n\nCriticalLevel\n\n\nErrorLevel\n\n\nWarningLevel\n\n\nNoticeLevel\n\n\nInfoLevel\n\n\nDebugLevel\n\n\nSynonyms:\nwisp.LogLevel\nwisp LogLevel","url":"wisp.html#LogLevel"},{"doc":"wisp","title":"Request","content":"pub type Request =\n  HttpRequest(internal.Connection)\n A convenient alias for a HTTP request with a Wisp connection as the body.\n\n\nSynonyms:\nwisp.Request\nwisp Request","url":"wisp.html#Request"},{"doc":"wisp","title":"Response","content":"pub type Response =\n  HttpResponse(Body)\n An alias for a HTTP response containing a `Body`.\n\nSynonyms:\nwisp.Response\nwisp Response","url":"wisp.html#Response"},{"doc":"wisp","title":"Security","content":"pub type Security {\n  PlainText\n  Signed\n}\n\nPlainText\n The value is store as plain text without any additional security.\n The client will be able to read and modify the value, and create new values.\n\nSigned\n The value is signed to prevent modification.\n The client will be able to read the value but not modify it, or create new\n values.\n\nSynonyms:\nwisp.Security\nwisp Security","url":"wisp.html#Security"},{"doc":"wisp","title":"UploadedFile","content":"pub type UploadedFile {\n  UploadedFile(file_name: String, path: String)\n}\n\nUploadedFile(file_name: String, path: String)\n\nfile_name\n&lt;p&gt;The name that was given to the file in the form.\nThis is user input and should not be trusted.&lt;/p&gt;\n\npath\n&lt;p&gt;The location of the file on the server.\nThis is a temporary file and will be deleted when the request has\nfinished being handled.&lt;/p&gt;\n\nSynonyms:\nwisp.UploadedFile\nwisp UploadedFile","url":"wisp.html#UploadedFile"},{"doc":"wisp","title":"path_segments","content":"pub const path_segments: fn(Request(a)) -&gt; List(String)\n Return the non-empty segments of a request path.\n\n # Examples\n\n \n &gt; request.new()\n &gt; |&gt; request.set_path(&quot;/one/two/three&quot;)\n &gt; |&gt; wisp.path_segments\n [&quot;one&quot;, &quot;two&quot;, &quot;three&quot;]\n \n\nSynonyms:\nwisp.path_segments\nwisp path_segments","url":"wisp.html#path_segments"},{"doc":"wisp","title":"priv_directory","content":"pub const priv_directory: fn(String) -&gt; Result(String, Nil)\n Returns the path of a package&#39;s `priv` directory, where extra non-Gleam\n or Erlang files are typically kept.\n\n Returns an error if no package was found with the given name.\n\n # Example\n\n \n &gt; erlang.priv_directory(&quot;my_app&quot;)\n // -&gt; Ok(&quot;/some/location/my_app/priv&quot;)\n \n\nSynonyms:\nwisp.priv_directory\nwisp priv_directory","url":"wisp.html#priv_directory"},{"doc":"wisp","title":"set_header","content":"pub const set_header: fn(Response(a), String, String) -&gt;\n  Response(a)\n Set a given header to a given value, replacing any existing value.\n\n # Examples\n\n \n &gt; wisp.ok()\n &gt; |&gt; wisp.set_header(&quot;content-type&quot;, &quot;application/json&quot;)\n Request(200, [#(&quot;content-type&quot;, &quot;application/json&quot;)], Empty)\n \n\nSynonyms:\nwisp.set_header\nwisp set_header","url":"wisp.html#set_header"},{"doc":"wisp","title":"accepted","content":"pub fn accepted() -&gt; Response(Body)\n Create an empty response with status code 202: Accepted.\n\n # Examples\n\n \n accepted()\n // -&gt; Response(202, [], Empty)\n \n\nSynonyms:\nwisp.accepted\nwisp accepted","url":"wisp.html#accepted"},{"doc":"wisp","title":"bad_request","content":"pub fn bad_request() -&gt; Response(Body)\n Create an empty response with status code 400: Bad request.\n\n # Examples\n\n \n bad_request()\n // -&gt; Response(400, [], Empty)\n \n\nSynonyms:\nwisp.bad_request\nwisp bad_request","url":"wisp.html#bad_request"},{"doc":"wisp","title":"configure_logger","content":"pub fn configure_logger() -&gt; Nil\n Configure the Erlang logger, setting the minimum log level to `info`, to be\n called when your application starts.\n\n You may wish to use an alternative for this such as one provided by a more\n sophisticated logging library.\n\n In future this function may be extended to change the output format.\n\nSynonyms:\nwisp.configure_logger\nwisp configure_logger","url":"wisp.html#configure_logger"},{"doc":"wisp","title":"create_canned_connection","content":"pub fn create_canned_connection(\n  body: BitArray,\n  secret_key_base: String,\n) -&gt; Connection\n Create a connection which will return the given body when read.\n\n This function is intended for use in tests, though you probably want the\n `wisp/testing` module instead.\n\nSynonyms:\nwisp.create_canned_connection\nwisp create_canned_connection","url":"wisp.html#create_canned_connection"},{"doc":"wisp","title":"created","content":"pub fn created() -&gt; Response(Body)\n Create an empty response with status code 201: Created.\n\n # Examples\n\n \n created()\n // -&gt; Response(201, [], Empty)\n \n\nSynonyms:\nwisp.created\nwisp created","url":"wisp.html#created"},{"doc":"wisp","title":"delete_temporary_files","content":"pub fn delete_temporary_files(\n  request: Request(Connection),\n) -&gt; Result(Nil, FileError)\n Delete any temporary files created for the given request.\n\n If you are using the Mist adapter or another compliant web server\n adapter then this file will be deleted for you when the request is complete.\n Otherwise you will need to call this function yourself.\n\nSynonyms:\nwisp.delete_temporary_files\nwisp delete_temporary_files","url":"wisp.html#delete_temporary_files"},{"doc":"wisp","title":"entity_too_large","content":"pub fn entity_too_large() -&gt; Response(Body)\n Create an empty response with status code 413: Entity too large.\n\n # Examples\n\n \n entity_too_large()\n // -&gt; Response(413, [], Empty)\n \n\nSynonyms:\nwisp.entity_too_large\nwisp entity_too_large","url":"wisp.html#entity_too_large"},{"doc":"wisp","title":"escape_html","content":"pub fn escape_html(content: String) -&gt; String\n Escape a string so that it can be safely included in a HTML document.\n\n Any content provided by the user should be escaped before being included in\n a HTML document to prevent cross-site scripting attacks.\n\n # Examples\n\n \n escape_html(&quot;&lt;h1&gt;Hello, Joe!&lt;/h1&gt;&quot;)\n // -&gt; &quot;&amp;lt;h1&amp;gt;Hello, Joe!&amp;lt;/h1&amp;gt;&quot;\n \n\nSynonyms:\nwisp.escape_html\nwisp escape_html","url":"wisp.html#escape_html"},{"doc":"wisp","title":"file_download","content":"pub fn file_download(\n  response: Response(Body),\n  named name: String,\n  from path: String,\n) -&gt; Response(Body)\n Send a file from the disc as a file download.\n\n The operating system `send_file` function is used to efficiently send the\n file over the network socket without reading the entire file into memory.\n\n The `content-disposition` header will be set to `attachment;\n filename=&quot;name&quot;` to ensure the file is downloaded by the browser. This is\n especially good for files that the browser would otherwise attempt to open\n as this can result in cross-site scripting vulnerabilities.\n\n If you wish to not set the `content-disposition` header you could use the\n `set_body` function with the `File` body variant.\n\n # Examples\n\n \n response(200)\n |&gt; file_download(named: &quot;myfile.txt&quot;, from: &quot;/tmp/myfile.txt&quot;)\n // -&gt; Response(\n //   200,\n //   [#(&quot;content-disposition&quot;, &quot;attachment; filename=\\&quot;myfile.txt\\&quot;&quot;)],\n //   File(&quot;/tmp/myfile.txt&quot;),\n // )\n \n\nSynonyms:\nwisp.file_download\nwisp file_download","url":"wisp.html#file_download"},{"doc":"wisp","title":"file_download_from_memory","content":"pub fn file_download_from_memory(\n  response: Response(Body),\n  named name: String,\n  containing data: BytesTree,\n) -&gt; Response(Body)\n Send a file from memory as a file download.\n\n If your file is already on the disc use `file_download` instead, to avoid\n having to read the file into memory to send it.\n\n The `content-disposition` header will be set to `attachment;\n filename=&quot;name&quot;` to ensure the file is downloaded by the browser. This is\n especially good for files that the browser would otherwise attempt to open\n as this can result in cross-site scripting vulnerabilities.\n\n # Examples\n\n \n let content = bytes_tree.from_string(&quot;Hello, Joe!&quot;)\n response(200)\n |&gt; file_download_from_memory(named: &quot;myfile.txt&quot;, containing: content)\n // -&gt; Response(\n //   200,\n //   [#(&quot;content-disposition&quot;, &quot;attachment; filename=\\&quot;myfile.txt\\&quot;&quot;)],\n //   File(&quot;/tmp/myfile.txt&quot;),\n // )\n \n\nSynonyms:\nwisp.file_download_from_memory\nwisp file_download_from_memory","url":"wisp.html#file_download_from_memory"},{"doc":"wisp","title":"get_cookie","content":"pub fn get_cookie(\n  request: Request(Connection),\n  name: String,\n  security: Security,\n) -&gt; Result(String, Nil)\n Get a cookie from the request.\n\n If a cookie is missing, found to be malformed, or the signature is invalid\n for a signed cookie, then `Error(Nil)` is returned.\n\n \n wisp.get_cookie(request, &quot;group&quot;, wisp.PlainText)\n // -&gt; Ok(&quot;A&quot;)\n \n\nSynonyms:\nwisp.get_cookie\nwisp get_cookie","url":"wisp.html#get_cookie"},{"doc":"wisp","title":"get_max_body_size","content":"pub fn get_max_body_size(request: Request(Connection)) -&gt; Int\n Get the maximum permitted size of a request body of the request in bytes.\n\nSynonyms:\nwisp.get_max_body_size\nwisp get_max_body_size","url":"wisp.html#get_max_body_size"},{"doc":"wisp","title":"get_max_files_size","content":"pub fn get_max_files_size(request: Request(Connection)) -&gt; Int\n Get the maximum permitted total size of a files uploaded by a request in\n bytes.\n\nSynonyms:\nwisp.get_max_files_size\nwisp get_max_files_size","url":"wisp.html#get_max_files_size"},{"doc":"wisp","title":"get_query","content":"pub fn get_query(\n  request: Request(Connection),\n) -&gt; List(#(String, String))\n Parse the query parameters of a request into a list of key-value pairs. The\n `key_find` function in the `gleam/list` stdlib module may be useful for\n finding values in the list.\n\n Query parameter names do not have to be unique and so may appear multiple\n times in the list.\n\nSynonyms:\nwisp.get_query\nwisp get_query","url":"wisp.html#get_query"},{"doc":"wisp","title":"get_read_chunk_size","content":"pub fn get_read_chunk_size(request: Request(Connection)) -&gt; Int\n Get the size limit for each chunk of the request body when read from the\n client.\n\nSynonyms:\nwisp.get_read_chunk_size\nwisp get_read_chunk_size","url":"wisp.html#get_read_chunk_size"},{"doc":"wisp","title":"get_secret_key_base","content":"pub fn get_secret_key_base(\n  request: Request(Connection),\n) -&gt; String\n Get the secret key base used to sign cookies and other sensitive data.\n\nSynonyms:\nwisp.get_secret_key_base\nwisp get_secret_key_base","url":"wisp.html#get_secret_key_base"},{"doc":"wisp","title":"handle_head","content":"pub fn handle_head(\n  req: Request(Connection),\n  next handler: fn(Request(Connection)) -&gt; Response(Body),\n) -&gt; Response(Body)\n A middleware function that converts `HEAD` requests to `GET` requests,\n handles the request, and then discards the response body. This is useful so\n that your application can handle `HEAD` requests without having to implement\n handlers for them.\n\n The `x-original-method` header is set to `&quot;HEAD&quot;` for requests that were\n originally `HEAD` requests.\n\n # Examples\n\n \n fn handle_request(req: Request) -&gt; Response {\n   use req &lt;- wisp.handle_head(req)\n   // ...\n }\n \n\nSynonyms:\nwisp.handle_head\nwisp handle_head","url":"wisp.html#handle_head"},{"doc":"wisp","title":"html_body","content":"pub fn html_body(\n  response: Response(Body),\n  html: StringTree,\n) -&gt; Response(Body)\n Set the body of a response to a given HTML document, and set the\n `content-type` header to `text/html`.\n\n The body is expected to be valid HTML, though this is not validated.\n\n # Examples\n\n \n let body = string_tree.from_string(&quot;&lt;h1&gt;Hello, Joe!&lt;/h1&gt;&quot;)\n response(201)\n |&gt; html_body(body)\n // -&gt; Response(201, [#(&quot;content-type&quot;, &quot;text/html; charset=utf-8&quot;)], Text(body))\n \n\nSynonyms:\nwisp.html_body\nwisp html_body","url":"wisp.html#html_body"},{"doc":"wisp","title":"html_response","content":"pub fn html_response(\n  html: StringTree,\n  status: Int,\n) -&gt; Response(Body)\n Create a HTML response.\n\n The body is expected to be valid HTML, though this is not validated.\n The `content-type` header will be set to `text/html`.\n\n # Examples\n\n \n let body = string_tree.from_string(&quot;&lt;h1&gt;Hello, Joe!&lt;/h1&gt;&quot;)\n html_response(body, 200)\n // -&gt; Response(200, [#(&quot;content-type&quot;, &quot;text/html&quot;)], Text(body))\n \n\nSynonyms:\nwisp.html_response\nwisp html_response","url":"wisp.html#html_response"},{"doc":"wisp","title":"internal_server_error","content":"pub fn internal_server_error() -&gt; Response(Body)\n Create an empty response with status code 500: Internal server error.\n\n # Examples\n\n \n internal_server_error()\n // -&gt; Response(500, [], Empty)\n \n\nSynonyms:\nwisp.internal_server_error\nwisp internal_server_error","url":"wisp.html#internal_server_error"},{"doc":"wisp","title":"json_body","content":"pub fn json_body(\n  response: Response(Body),\n  json: StringTree,\n) -&gt; Response(Body)\n Set the body of a response to a given JSON document, and set the\n `content-type` header to `application/json`.\n\n The body is expected to be valid JSON, though this is not validated.\n\n # Examples\n\n \n let body = string_tree.from_string(&quot;{\\&quot;name\\&quot;: \\&quot;Joe\\&quot;}&quot;)\n response(201)\n |&gt; json_body(body)\n // -&gt; Response(201, [#(&quot;content-type&quot;, &quot;application/json; charset=utf-8&quot;)], Text(body))\n \n\nSynonyms:\nwisp.json_body\nwisp json_body","url":"wisp.html#json_body"},{"doc":"wisp","title":"json_response","content":"pub fn json_response(\n  json: StringTree,\n  status: Int,\n) -&gt; Response(Body)\n Create a JSON response.\n\n The body is expected to be valid JSON, though this is not validated.\n The `content-type` header will be set to `application/json`.\n\n # Examples\n\n \n let body = string_tree.from_string(&quot;{\\&quot;name\\&quot;: \\&quot;Joe\\&quot;}&quot;)\n json_response(body, 200)\n // -&gt; Response(200, [#(&quot;content-type&quot;, &quot;application/json&quot;)], Text(body))\n \n\nSynonyms:\nwisp.json_response\nwisp json_response","url":"wisp.html#json_response"},{"doc":"wisp","title":"log_alert","content":"pub fn log_alert(message: String) -&gt; Nil\n Log a message to the Erlang logger with the level of `alert`.\n\n See the [Erlang logger documentation][1] for more information.\n\n [1]: https://www.erlang.org/doc/man/logger\n\nSynonyms:\nwisp.log_alert\nwisp log_alert","url":"wisp.html#log_alert"},{"doc":"wisp","title":"log_critical","content":"pub fn log_critical(message: String) -&gt; Nil\n Log a message to the Erlang logger with the level of `critical`.\n\n See the [Erlang logger documentation][1] for more information.\n\n [1]: https://www.erlang.org/doc/man/logger\n\nSynonyms:\nwisp.log_critical\nwisp log_critical","url":"wisp.html#log_critical"},{"doc":"wisp","title":"log_debug","content":"pub fn log_debug(message: String) -&gt; Nil\n Log a message to the Erlang logger with the level of `debug`.\n\n See the [Erlang logger documentation][1] for more information.\n\n [1]: https://www.erlang.org/doc/man/logger\n\nSynonyms:\nwisp.log_debug\nwisp log_debug","url":"wisp.html#log_debug"},{"doc":"wisp","title":"log_emergency","content":"pub fn log_emergency(message: String) -&gt; Nil\n Log a message to the Erlang logger with the level of `emergency`.\n\n See the [Erlang logger documentation][1] for more information.\n\n [1]: https://www.erlang.org/doc/man/logger\n\nSynonyms:\nwisp.log_emergency\nwisp log_emergency","url":"wisp.html#log_emergency"},{"doc":"wisp","title":"log_error","content":"pub fn log_error(message: String) -&gt; Nil\n Log a message to the Erlang logger with the level of `error`.\n\n See the [Erlang logger documentation][1] for more information.\n\n [1]: https://www.erlang.org/doc/man/logger\n\nSynonyms:\nwisp.log_error\nwisp log_error","url":"wisp.html#log_error"},{"doc":"wisp","title":"log_info","content":"pub fn log_info(message: String) -&gt; Nil\n Log a message to the Erlang logger with the level of `info`.\n\n See the [Erlang logger documentation][1] for more information.\n\n [1]: https://www.erlang.org/doc/man/logger\n\nSynonyms:\nwisp.log_info\nwisp log_info","url":"wisp.html#log_info"},{"doc":"wisp","title":"log_notice","content":"pub fn log_notice(message: String) -&gt; Nil\n Log a message to the Erlang logger with the level of `notice`.\n\n See the [Erlang logger documentation][1] for more information.\n\n [1]: https://www.erlang.org/doc/man/logger\n\nSynonyms:\nwisp.log_notice\nwisp log_notice","url":"wisp.html#log_notice"},{"doc":"wisp","title":"log_request","content":"pub fn log_request(\n  req: Request(Connection),\n  handler: fn() -&gt; Response(Body),\n) -&gt; Response(Body)\n A middleware function that logs details about the request and response.\n\n The format used logged by this middleware may change in future versions of\n Wisp.\n\n # Examples\n\n \n fn handle_request(req: Request) -&gt; Response {\n   use &lt;- wisp.log_request(req)\n   // ...\n }\n \n\nSynonyms:\nwisp.log_request\nwisp log_request","url":"wisp.html#log_request"},{"doc":"wisp","title":"log_warning","content":"pub fn log_warning(message: String) -&gt; Nil\n Log a message to the Erlang logger with the level of `warning`.\n\n See the [Erlang logger documentation][1] for more information.\n\n [1]: https://www.erlang.org/doc/man/logger\n\nSynonyms:\nwisp.log_warning\nwisp log_warning","url":"wisp.html#log_warning"},{"doc":"wisp","title":"method_not_allowed","content":"pub fn method_not_allowed(\n  allowed methods: List(Method),\n) -&gt; Response(Body)\n Create an empty response with status code 405: Method Not Allowed. Use this\n when a request does not have an appropriate method to be handled.\n\n The `allow` header will be set to a comma separated list of the permitted\n methods.\n\n # Examples\n\n \n method_not_allowed(allowed: [Get, Post])\n // -&gt; Response(405, [#(&quot;allow&quot;, &quot;GET, POST&quot;)], Empty)\n \n\nSynonyms:\nwisp.method_not_allowed\nwisp method_not_allowed","url":"wisp.html#method_not_allowed"},{"doc":"wisp","title":"method_override","content":"pub fn method_override(request: Request(a)) -&gt; Request(a)\n This function overrides an incoming POST request with a method given in\n the request&#39;s `_method` query paramerter. This is useful as web browsers\n typically only support GET and POST requests, but our application may\n expect other HTTP methods that are more semantically correct.\n\n The methods PUT, PATCH, and DELETE are accepted for overriding, all others\n are ignored.\n\n The `_method` query paramerter can be specified in a HTML form like so:\n\n    &lt;form method=&quot;POST&quot; action=&quot;/item/1?_method=DELETE&quot;&gt;\n      &lt;button type=&quot;submit&quot;&gt;Delete item&lt;/button&gt;\n    &lt;/form&gt;\n\n # Examples\n\n \n fn handle_request(request: Request) -&gt; Response {\n   let request = wisp.method_override(request)\n   // The method has now been overridden if appropriate\n }\n \n\nSynonyms:\nwisp.method_override\nwisp method_override","url":"wisp.html#method_override"},{"doc":"wisp","title":"moved_permanently","content":"pub fn moved_permanently(to url: String) -&gt; Response(Body)\n Create an empty response with status code 308: Moved Permanently, and the\n `location` header set to the given URL. Used to redirect the client to\n another page.\n\n This redirect is permanent and the client is expected to cache the new\n location, using it for future requests.\n\n # Examples\n\n \n moved_permanently(to: &quot;https://example.com&quot;)\n // -&gt; Response(308, [#(&quot;location&quot;, &quot;https://example.com&quot;)], Empty)\n \n\nSynonyms:\nwisp.moved_permanently\nwisp moved_permanently","url":"wisp.html#moved_permanently"},{"doc":"wisp","title":"new_temporary_file","content":"pub fn new_temporary_file(\n  request: Request(Connection),\n) -&gt; Result(String, FileError)\n Create a new temporary directory for the given request.\n\n If you are using the Mist adapter or another compliant web server\n adapter then this file will be deleted for you when the request is complete.\n Otherwise you will need to call the `delete_temporary_files` function\n yourself.\n\nSynonyms:\nwisp.new_temporary_file\nwisp new_temporary_file","url":"wisp.html#new_temporary_file"},{"doc":"wisp","title":"no_content","content":"pub fn no_content() -&gt; Response(Body)\n Create an empty response with status code 204: No content.\n\n # Examples\n\n \n no_content()\n // -&gt; Response(204, [], Empty)\n \n\nSynonyms:\nwisp.no_content\nwisp no_content","url":"wisp.html#no_content"},{"doc":"wisp","title":"not_found","content":"pub fn not_found() -&gt; Response(Body)\n Create an empty response with status code 404: No content.\n\n # Examples\n\n \n not_found()\n // -&gt; Response(404, [], Empty)\n \n\nSynonyms:\nwisp.not_found\nwisp not_found","url":"wisp.html#not_found"},{"doc":"wisp","title":"ok","content":"pub fn ok() -&gt; Response(Body)\n Create an empty response with status code 200: OK.\n\n # Examples\n\n \n ok()\n // -&gt; Response(200, [], Empty)\n \n\nSynonyms:\nwisp.ok\nwisp ok","url":"wisp.html#ok"},{"doc":"wisp","title":"random_string","content":"pub fn random_string(length: Int) -&gt; String\n Generate a random string of the given length.\n\nSynonyms:\nwisp.random_string\nwisp random_string","url":"wisp.html#random_string"},{"doc":"wisp","title":"read_body_to_bitstring","content":"pub fn read_body_to_bitstring(\n  request: Request(Connection),\n) -&gt; Result(BitArray, Nil)\n Read the entire body of the request as a bit string.\n\n You may instead wish to use the `require_bit_array_body` or the\n `require_string_body` middleware functions instead.\n\n This function does not cache the body in any way, so if you call this\n function (or any other body reading function) more than once it may hang or\n return an incorrect value, depending on the underlying web server. It is the\n responsibility of the caller to cache the body if it is needed multiple\n times.\n\n If the body is larger than the `max_body_size` limit then an empty response\n with status code 413: Entity too large will be returned to the client.\n\nSynonyms:\nwisp.read_body_to_bitstring\nwisp read_body_to_bitstring","url":"wisp.html#read_body_to_bitstring"},{"doc":"wisp","title":"redirect","content":"pub fn redirect(to url: String) -&gt; Response(Body)\n Create an empty response with status code 303: See Other, and the `location`\n header set to the given URL. Used to redirect the client to another page.\n\n # Examples\n\n \n redirect(to: &quot;https://example.com&quot;)\n // -&gt; Response(303, [#(&quot;location&quot;, &quot;https://example.com&quot;)], Empty)\n \n\nSynonyms:\nwisp.redirect\nwisp redirect","url":"wisp.html#redirect"},{"doc":"wisp","title":"require_bit_array_body","content":"pub fn require_bit_array_body(\n  request: Request(Connection),\n  next: fn(BitArray) -&gt; Response(Body),\n) -&gt; Response(Body)\n A middleware function which reads the entire body of the request as a bit\n string.\n\n This function does not cache the body in any way, so if you call this\n function (or any other body reading function) more than once it may hang or\n return an incorrect value, depending on the underlying web server. It is the\n responsibility of the caller to cache the body if it is needed multiple\n times.\n\n If the body is larger than the `max_body_size` limit then an empty response\n with status code 413: Entity too large will be returned to the client.\n\n # Examples\n\n \n fn handle_request(request: Request) -&gt; Response {\n   use body &lt;- wisp.require_string_body(request)\n   // ...\n }\n \n\nSynonyms:\nwisp.require_bit_array_body\nwisp require_bit_array_body","url":"wisp.html#require_bit_array_body"},{"doc":"wisp","title":"require_content_type","content":"pub fn require_content_type(\n  request: Request(Connection),\n  expected: String,\n  next: fn() -&gt; Response(Body),\n) -&gt; Response(Body)\n This middleware function ensures that the request has a value for the\n `content-type` header, returning an empty response with status code 415:\n Unsupported media type if the header is not the expected value\n\n # Examples\n\n \n fn handle_request(request: Request) -&gt; Response {\n   use &lt;- wisp.require_content_type(request, &quot;application/json&quot;)\n   // ...\n }\n \n\nSynonyms:\nwisp.require_content_type\nwisp require_content_type","url":"wisp.html#require_content_type"},{"doc":"wisp","title":"require_form","content":"pub fn require_form(\n  request: Request(Connection),\n  next: fn(FormData) -&gt; Response(Body),\n) -&gt; Response(Body)\n A middleware which extracts form data from the body of a request that is\n encoded as either `application/x-www-form-urlencoded` or\n `multipart/form-data`.\n\n Extracted fields are sorted into alphabetical order by key, so if you wish\n to use pattern matching the order can be relied upon.\n\n \n fn handle_request(request: Request) -&gt; Response {\n   use form &lt;- wisp.require_form(request)\n   case form.values {\n     [#(&quot;password&quot;, pass), #(&quot;username&quot;, username)] -&gt; // ...\n     _ -&gt; // ...\n   }\n }\n \n\n The `set_max_body_size`, `set_max_files_size`, and `set_read_chunk_size` can\n be used to configure the reading of the request body.\n\n Any file uploads will streamed into temporary files on disc. These files are\n automatically deleted when the request handler returns, so if you wish to\n use them after the request has completed you will need to move them to a new\n location.\n\n If the request does not have a recognised `content-type` header then an\n empty response with status code 415: Unsupported media type will be returned\n to the client.\n\n If the request body is larger than the `max_body_size` or `max_files_size`\n limits then an empty response with status code 413: Entity too large will be\n returned to the client.\n\n If the body cannot be parsed successfully then an empty response with status\n code 400: Bad request will be returned to the client.\n\nSynonyms:\nwisp.require_form\nwisp require_form","url":"wisp.html#require_form"},{"doc":"wisp","title":"require_json","content":"pub fn require_json(\n  request: Request(Connection),\n  next: fn(Dynamic) -&gt; Response(Body),\n) -&gt; Response(Body)\n A middleware which extracts JSON from the body of a request.\n\n \n fn handle_request(request: Request) -&gt; Response {\n   use json &lt;- wisp.require_json(request)\n   // decode and use JSON here...\n }\n \n\n The `set_max_body_size` and `set_read_chunk_size` can be used to configure\n the reading of the request body.\n\n If the request does not have the `content-type` set to `application/json` an\n empty response with status code 415: Unsupported media type will be returned\n to the client.\n\n If the request body is larger than the `max_body_size` or `max_files_size`\n limits then an empty response with status code 413: Entity too large will be\n returned to the client.\n\n If the body cannot be parsed successfully then an empty response with status\n code 400: Bad request will be returned to the client.\n\nSynonyms:\nwisp.require_json\nwisp require_json","url":"wisp.html#require_json"},{"doc":"wisp","title":"require_method","content":"pub fn require_method(\n  request: Request(a),\n  method: Method,\n  next: fn() -&gt; Response(Body),\n) -&gt; Response(Body)\n This middleware function ensures that the request has a specific HTTP\n method, returning an empty response with status code 405: Method not allowed\n if the method is not correct.\n\n # Examples\n\n \n fn handle_request(request: Request) -&gt; Response {\n   use &lt;- wisp.require_method(request, http.Patch)\n   // ...\n }\n \n\nSynonyms:\nwisp.require_method\nwisp require_method","url":"wisp.html#require_method"},{"doc":"wisp","title":"require_string_body","content":"pub fn require_string_body(\n  request: Request(Connection),\n  next: fn(String) -&gt; Response(Body),\n) -&gt; Response(Body)\n A middleware function which reads the entire body of the request as a string.\n\n This function does not cache the body in any way, so if you call this\n function (or any other body reading function) more than once it may hang or\n return an incorrect value, depending on the underlying web server. It is the\n responsibility of the caller to cache the body if it is needed multiple\n times.\n\n If the body is larger than the `max_body_size` limit then an empty response\n with status code 413: Entity too large will be returned to the client.\n\n If the body is found not to be valid UTF-8 then an empty response with\n status code 400: Bad request will be returned to the client.\n\n # Examples\n\n \n fn handle_request(request: Request) -&gt; Response {\n   use body &lt;- wisp.require_string_body(request)\n   // ...\n }\n \n\nSynonyms:\nwisp.require_string_body\nwisp require_string_body","url":"wisp.html#require_string_body"},{"doc":"wisp","title":"rescue_crashes","content":"pub fn rescue_crashes(\n  handler: fn() -&gt; Response(Body),\n) -&gt; Response(Body)\n A middleware function that rescues crashes and returns an empty response\n with status code 500: Internal server error.\n\n # Examples\n\n \n fn handle_request(req: Request) -&gt; Response {\n   use &lt;- wisp.rescue_crashes\n   // ...\n }\n \n\nSynonyms:\nwisp.rescue_crashes\nwisp rescue_crashes","url":"wisp.html#rescue_crashes"},{"doc":"wisp","title":"response","content":"pub fn response(status: Int) -&gt; Response(Body)\n Create an empty response with the given status code.\n\n # Examples\n\n \n response(200)\n // -&gt; Response(200, [], Empty)\n \n\nSynonyms:\nwisp.response\nwisp response","url":"wisp.html#response"},{"doc":"wisp","title":"serve_static","content":"pub fn serve_static(\n  req: Request(Connection),\n  under prefix: String,\n  from directory: String,\n  next handler: fn() -&gt; Response(Body),\n) -&gt; Response(Body)\n A middleware function that serves files from a directory, along with a\n suitable `content-type` header for known file extensions.\n\n Files are sent using the `File` response body type, so they will be sent\n directly to the client from the disc, without being read into memory.\n\n The `under` parameter is the request path prefix that must match for the\n file to be served.\n\n | `under`   | `from`  | `request.path`     | `file`                  |\n |-----------|---------|--------------------|-------------------------|\n | `/static` | `/data` | `/static/file.txt` | `/data/file.txt`        |\n | ``        | `/data` | `/static/file.txt` | `/data/static/file.txt` |\n | `/static` | ``      | `/static/file.txt` | `file.txt`              |\n\n This middleware will discard any `..` path segments in the request path to\n prevent the client from accessing files outside of the directory. It is\n advised not to serve a directory that contains your source code, application\n configuration, database, or other private files.\n\n # Examples\n\n \n fn handle_request(req: Request) -&gt; Response {\n   use &lt;- wisp.serve_static(req, under: &quot;/static&quot;, from: &quot;/public&quot;)\n   // ...\n }\n \n\n Typically you static assets may be kept in your project in a directory\n called `priv`. The `priv_directory` function can be used to get a path to\n this directory.\n\n \n fn handle_request(req: Request) -&gt; Response {\n   let assert Ok(priv) = priv_directory(&quot;my_application&quot;)\n   use &lt;- wisp.serve_static(req, under: &quot;/static&quot;, from: priv)\n   // ...\n }\n \n\nSynonyms:\nwisp.serve_static\nwisp serve_static","url":"wisp.html#serve_static"},{"doc":"wisp","title":"set_body","content":"pub fn set_body(\n  response: Response(Body),\n  body: Body,\n) -&gt; Response(Body)\n Set the body of a response.\n\n # Examples\n\n \n response(200)\n |&gt; set_body(File(&quot;/tmp/myfile.txt&quot;))\n // -&gt; Response(200, [], File(&quot;/tmp/myfile.txt&quot;))\n \n\nSynonyms:\nwisp.set_body\nwisp set_body","url":"wisp.html#set_body"},{"doc":"wisp","title":"set_cookie","content":"pub fn set_cookie(\n  response response: Response(Body),\n  request request: Request(Connection),\n  name name: String,\n  value value: String,\n  security security: Security,\n  max_age max_age: Int,\n) -&gt; Response(Body)\n Set a cookie on the response. After `max_age` seconds the cookie will be\n expired by the client.\n\n This function will sign the value if the `security` parameter is set to\n `Signed`, making it so the cookie cannot be tampered with by the client.\n\n Values are base64 encoded so they can contain any characters you want, even\n if they would not be permitted directly in a cookie.\n\n Cookies are set using `gleam_http`&#39;s default attributes for HTTPS. If you\n wish for more control over the cookie attributes then you may want to use\n the `gleam/http/cookie` module from the `gleam_http` package instead of this\n function. Be sure to sign and escape the cookie value as needed.\n\n # Examples\n\n Setting a plain text cookie that the client can read and modify:\n\n \n wisp.ok()\n |&gt; wisp.set_cookie(request, &quot;id&quot;, &quot;123&quot;, wisp.PlainText, 60 * 60)\n \n\n Setting a signed cookie that the client can read but not modify:\n\n \n wisp.ok()\n |&gt; wisp.set_cookie(request, &quot;id&quot;, value, wisp.Signed, 60 * 60)\n \n\nSynonyms:\nwisp.set_cookie\nwisp set_cookie","url":"wisp.html#set_cookie"},{"doc":"wisp","title":"set_logger_level","content":"pub fn set_logger_level(log_level: LogLevel) -&gt; Nil\n Set the log level of the Erlang logger to `log_level`.\n\n See the [Erlang logger documentation][1] for more information.\n\n [1]: https://www.erlang.org/doc/man/logger\n\nSynonyms:\nwisp.set_logger_level\nwisp set_logger_level","url":"wisp.html#set_logger_level"},{"doc":"wisp","title":"set_max_body_size","content":"pub fn set_max_body_size(\n  request: Request(Connection),\n  size: Int,\n) -&gt; Request(Connection)\n Set the maximum permitted size of a request body of the request in bytes.\n\n If a body is larger than this size attempting to read the body will result\n in a response with status code 413: Entity too large will be returned to the\n client.\n\n This limit only applies for headers and bodies that get read into memory.\n Part of a multipart body that contain files and so are streamed to disc\n instead use the `max_files_size` limit.\n\nSynonyms:\nwisp.set_max_body_size\nwisp set_max_body_size","url":"wisp.html#set_max_body_size"},{"doc":"wisp","title":"set_max_files_size","content":"pub fn set_max_files_size(\n  request: Request(Connection),\n  size: Int,\n) -&gt; Request(Connection)\n Set the maximum permitted size of all files uploaded by a request, in bytes.\n\n If a request contains fails which are larger in total than this size\n then attempting to read the body will result in a response with status code\n 413: Entity too large will be returned to the client.\n\n This limit only applies for files in a multipart body that get streamed to\n disc. For headers and other content that gets read into memory use the\n `max_body_size` limit.\n\nSynonyms:\nwisp.set_max_files_size\nwisp set_max_files_size","url":"wisp.html#set_max_files_size"},{"doc":"wisp","title":"set_read_chunk_size","content":"pub fn set_read_chunk_size(\n  request: Request(Connection),\n  size: Int,\n) -&gt; Request(Connection)\n The the size limit for each chunk of the request body when read from the\n client.\n\n This value is passed to the underlying web server when reading the body and\n the exact size of chunks read depends on the server implementation. It most\n likely will read chunks smaller than this size if not yet enough data has\n been received from the client.\n\nSynonyms:\nwisp.set_read_chunk_size\nwisp set_read_chunk_size","url":"wisp.html#set_read_chunk_size"},{"doc":"wisp","title":"set_secret_key_base","content":"pub fn set_secret_key_base(\n  request: Request(Connection),\n  key: String,\n) -&gt; Request(Connection)\n Set the secret key base used to sign cookies and other sensitive data.\n\n This key must be at least 64 bytes long and should be kept secret. Anyone\n with this secret will be able to manipulate signed cookies and other sensitive\n data.\n\n # Panics\n\n This function will panic if the key is less than 64 bytes long.\n\nSynonyms:\nwisp.set_secret_key_base\nwisp set_secret_key_base","url":"wisp.html#set_secret_key_base"},{"doc":"wisp","title":"sign_message","content":"pub fn sign_message(\n  request: Request(Connection),\n  message: BitArray,\n  algorithm: HashAlgorithm,\n) -&gt; String\n Sign a message which can later be verified using the `verify_signed_message`\n function to detect if the message has been tampered with.\n\n Signed messages are not encrypted and can be read by anyone. They are not\n suitable for storing sensitive information.\n\n This function uses the secret key base from the request. If the secret\n changes then the signature will no longer be verifiable.\n\nSynonyms:\nwisp.sign_message\nwisp sign_message","url":"wisp.html#sign_message"},{"doc":"wisp","title":"string_body","content":"pub fn string_body(\n  response: Response(Body),\n  content: String,\n) -&gt; Response(Body)\n Set the body of a response to a given string.\n\n You likely want to also set the request `content-type` header to an\n appropriate value for the format of the content.\n\n # Examples\n\n \n let body =\n response(201)\n |&gt; string_body(&quot;Hello, Joe!&quot;)\n // -&gt; Response(\n //   201,\n //   [],\n //   Text(string_tree.from_string(&quot;Hello, Joe&quot;))\n // )\n \n\nSynonyms:\nwisp.string_body\nwisp string_body","url":"wisp.html#string_body"},{"doc":"wisp","title":"string_tree_body","content":"pub fn string_tree_body(\n  response: Response(Body),\n  content: StringTree,\n) -&gt; Response(Body)\n Set the body of a response to a given string tree.\n\n You likely want to also set the request `content-type` header to an\n appropriate value for the format of the content.\n\n # Examples\n\n \n let body = string_tree.from_string(&quot;Hello, Joe!&quot;)\n response(201)\n |&gt; string_tree_body(body)\n // -&gt; Response(201, [], Text(body))\n \n\nSynonyms:\nwisp.string_tree_body\nwisp string_tree_body","url":"wisp.html#string_tree_body"},{"doc":"wisp","title":"unprocessable_entity","content":"pub fn unprocessable_entity() -&gt; Response(Body)\n Create an empty response with status code 422: Unprocessable entity.\n\n # Examples\n\n \n unprocessable_entity()\n // -&gt; Response(422, [], Empty)\n \n\nSynonyms:\nwisp.unprocessable_entity\nwisp unprocessable_entity","url":"wisp.html#unprocessable_entity"},{"doc":"wisp","title":"unsupported_media_type","content":"pub fn unsupported_media_type(\n  accept acceptable: List(String),\n) -&gt; Response(Body)\n Create an empty response with status code 415: Unsupported media type.\n\n The `allow` header will be set to a comma separated list of the permitted\n content-types.\n\n # Examples\n\n \n unsupported_media_type(accept: [&quot;application/json&quot;, &quot;text/plain&quot;])\n // -&gt; Response(415, [#(&quot;allow&quot;, &quot;application/json, text/plain&quot;)], Empty)\n \n\nSynonyms:\nwisp.unsupported_media_type\nwisp unsupported_media_type","url":"wisp.html#unsupported_media_type"},{"doc":"wisp","title":"verify_signed_message","content":"pub fn verify_signed_message(\n  request: Request(Connection),\n  message: String,\n) -&gt; Result(BitArray, Nil)\n Verify a signed message which was signed using the `sign_message` function.\n\n Returns the content of the message if the signature is valid, otherwise\n returns an error.\n\n This function uses the secret key base from the request. If the secret\n changes then the signature will no longer be verifiable.\n\nSynonyms:\nwisp.verify_signed_message\nwisp verify_signed_message","url":"wisp.html#verify_signed_message"},{"doc":"wisp","title":"wisp","content":"","url":"wisp.html"},{"doc":"wisp/testing","title":"default_secret_key_base","content":"pub const default_secret_key_base: String\n The default secret key base used for test requests.\n This should never be used outside of tests.\n\nSynonyms:\nwisp/testing.default_secret_key_base\nwisp/testing default_secret_key_base","url":"wisp/testing.html#default_secret_key_base"},{"doc":"wisp/testing","title":"set_header","content":"pub const set_header: fn(Request(a), String, String) -&gt;\n  Request(a)\n Set a header on a request.\n \n # Examples\n \n \n let request =\n   test.request(test.Get, &quot;/&quot;, [], &lt;&lt;&gt;&gt;)\n   |&gt; test.set_header(&quot;content-type&quot;, &quot;application/json&quot;)\n request.headers\n // =&gt; [#(&quot;content-type&quot;, &quot;application/json&quot;)]\n \nSynonyms:\nwisp/testing.set_header\nwisp/testing set_header","url":"wisp/testing.html#set_header"},{"doc":"wisp/testing","title":"bit_array_body","content":"pub fn bit_array_body(response: Response(Body)) -&gt; BitArray\n Read the body of a response as a bit string\n\n # Panics\n\n This function will panic if the response body is a file and the file cannot\n be read.\n\nSynonyms:\nwisp/testing.bit_array_body\nwisp/testing bit_array_body","url":"wisp/testing.html#bit_array_body"},{"doc":"wisp/testing","title":"connect","content":"pub fn connect(\n  path: String,\n  headers: List(#(String, String)),\n) -&gt; Request(Connection)\n Create a test HTTP request that can be used to test your request handler.\n \nSynonyms:\nwisp/testing.connect\nwisp/testing connect","url":"wisp/testing.html#connect"},{"doc":"wisp/testing","title":"delete","content":"pub fn delete(\n  path: String,\n  headers: List(#(String, String)),\n  body: String,\n) -&gt; Request(Connection)\n Create a test HTTP request that can be used to test your request handler.\n \nSynonyms:\nwisp/testing.delete\nwisp/testing delete","url":"wisp/testing.html#delete"},{"doc":"wisp/testing","title":"delete_form","content":"pub fn delete_form(\n  path: String,\n  headers: List(#(String, String)),\n  data: List(#(String, String)),\n) -&gt; Request(Connection)\n Create a test HTTP request that can be used to test your request handler.\n \n The body parameters are encoded as form data and the `content-type` header\n is set to `application/x-www-form-urlencoded`.\n \nSynonyms:\nwisp/testing.delete_form\nwisp/testing delete_form","url":"wisp/testing.html#delete_form"},{"doc":"wisp/testing","title":"delete_json","content":"pub fn delete_json(\n  path: String,\n  headers: List(#(String, String)),\n  data: Json,\n) -&gt; Request(Connection)\n Create a test HTTP request that can be used to test your request handler.\n \n The `content-type` header is set to `application/json`.\n \nSynonyms:\nwisp/testing.delete_json\nwisp/testing delete_json","url":"wisp/testing.html#delete_json"},{"doc":"wisp/testing","title":"get","content":"pub fn get(\n  path: String,\n  headers: List(#(String, String)),\n) -&gt; Request(Connection)\n Create a test HTTP request that can be used to test your request handler.\n \nSynonyms:\nwisp/testing.get\nwisp/testing get","url":"wisp/testing.html#get"},{"doc":"wisp/testing","title":"head","content":"pub fn head(\n  path: String,\n  headers: List(#(String, String)),\n) -&gt; Request(Connection)\n Create a test HTTP request that can be used to test your request handler.\n \nSynonyms:\nwisp/testing.head\nwisp/testing head","url":"wisp/testing.html#head"},{"doc":"wisp/testing","title":"options","content":"pub fn options(\n  path: String,\n  headers: List(#(String, String)),\n) -&gt; Request(Connection)\n Create a test HTTP request that can be used to test your request handler.\n \nSynonyms:\nwisp/testing.options\nwisp/testing options","url":"wisp/testing.html#options"},{"doc":"wisp/testing","title":"patch","content":"pub fn patch(\n  path: String,\n  headers: List(#(String, String)),\n  body: String,\n) -&gt; Request(Connection)\n Create a test HTTP request that can be used to test your request handler.\n \nSynonyms:\nwisp/testing.patch\nwisp/testing patch","url":"wisp/testing.html#patch"},{"doc":"wisp/testing","title":"patch_form","content":"pub fn patch_form(\n  path: String,\n  headers: List(#(String, String)),\n  data: List(#(String, String)),\n) -&gt; Request(Connection)\n Create a test HTTP request that can be used to test your request handler.\n \n The body parameters are encoded as form data and the `content-type` header is set to `application/x-www-form-urlencoded`.\n \nSynonyms:\nwisp/testing.patch_form\nwisp/testing patch_form","url":"wisp/testing.html#patch_form"},{"doc":"wisp/testing","title":"patch_json","content":"pub fn patch_json(\n  path: String,\n  headers: List(#(String, String)),\n  data: Json,\n) -&gt; Request(Connection)\n Create a test HTTP request that can be used to test your request handler.\n \n The `content-type` header is set to `application/json`.\n \nSynonyms:\nwisp/testing.patch_json\nwisp/testing patch_json","url":"wisp/testing.html#patch_json"},{"doc":"wisp/testing","title":"post","content":"pub fn post(\n  path: String,\n  headers: List(#(String, String)),\n  body: String,\n) -&gt; Request(Connection)\n Create a test HTTP request that can be used to test your request handler.\n \nSynonyms:\nwisp/testing.post\nwisp/testing post","url":"wisp/testing.html#post"},{"doc":"wisp/testing","title":"post_form","content":"pub fn post_form(\n  path: String,\n  headers: List(#(String, String)),\n  data: List(#(String, String)),\n) -&gt; Request(Connection)\n Create a test HTTP request that can be used to test your request handler.\n \n The body parameters are encoded as form data and the `content-type` header\n is set to `application/x-www-form-urlencoded`.\n \nSynonyms:\nwisp/testing.post_form\nwisp/testing post_form","url":"wisp/testing.html#post_form"},{"doc":"wisp/testing","title":"post_json","content":"pub fn post_json(\n  path: String,\n  headers: List(#(String, String)),\n  data: Json,\n) -&gt; Request(Connection)\n Create a test HTTP request that can be used to test your request handler.\n \n The `content-type` header is set to `application/json`.\n \nSynonyms:\nwisp/testing.post_json\nwisp/testing post_json","url":"wisp/testing.html#post_json"},{"doc":"wisp/testing","title":"put","content":"pub fn put(\n  path: String,\n  headers: List(#(String, String)),\n  body: String,\n) -&gt; Request(Connection)\n Create a test HTTP request that can be used to test your request handler.\n \nSynonyms:\nwisp/testing.put\nwisp/testing put","url":"wisp/testing.html#put"},{"doc":"wisp/testing","title":"put_form","content":"pub fn put_form(\n  path: String,\n  headers: List(#(String, String)),\n  data: List(#(String, String)),\n) -&gt; Request(Connection)\n Create a test HTTP request that can be used to test your request handler.\n \n The body parameters are encoded as form data and the `content-type` header\n is set to `application/x-www-form-urlencoded`.\n \nSynonyms:\nwisp/testing.put_form\nwisp/testing put_form","url":"wisp/testing.html#put_form"},{"doc":"wisp/testing","title":"put_json","content":"pub fn put_json(\n  path: String,\n  headers: List(#(String, String)),\n  data: Json,\n) -&gt; Request(Connection)\n Create a test HTTP request that can be used to test your request handler.\n \n The `content-type` header is set to `application/json`.\n \nSynonyms:\nwisp/testing.put_json\nwisp/testing put_json","url":"wisp/testing.html#put_json"},{"doc":"wisp/testing","title":"request","content":"pub fn request(\n  method: Method,\n  path: String,\n  headers: List(#(String, String)),\n  body: BitArray,\n) -&gt; Request(Connection)\n Create a test HTTP request that can be used to test your request handler\n functions.\n\n Note not all HTTP methods are expected to have an accompanying body, so when\n using this function directly over other functions such as `get` and `post`\n take care to ensure you are not providing a body when it is not expected.\n \n The `default_secret_key_base` constant is used as the secret key base for\n requests made with this function.\n\nSynonyms:\nwisp/testing.request\nwisp/testing request","url":"wisp/testing.html#request"},{"doc":"wisp/testing","title":"set_cookie","content":"pub fn set_cookie(\n  req: Request(Connection),\n  name: String,\n  value: String,\n  security: Security,\n) -&gt; Request(Connection)\n Set a cookie on the request.\n \nSynonyms:\nwisp/testing.set_cookie\nwisp/testing set_cookie","url":"wisp/testing.html#set_cookie"},{"doc":"wisp/testing","title":"string_body","content":"pub fn string_body(response: Response(Body)) -&gt; String\n Read the body of a response as a string.\n\n # Panics\n\n This function will panic if the response body is a file and the file cannot\n be read, or if it does not contain valid UTF-8.\n\nSynonyms:\nwisp/testing.string_body\nwisp/testing string_body","url":"wisp/testing.html#string_body"},{"doc":"wisp/testing","title":"trace","content":"pub fn trace(\n  path: String,\n  headers: List(#(String, String)),\n) -&gt; Request(Connection)\n Create a test HTTP request that can be used to test your request handler.\n \nSynonyms:\nwisp/testing.trace\nwisp/testing trace","url":"wisp/testing.html#trace"},{"doc":"wisp/testing","title":"wisp/testing","content":"","url":"wisp/testing.html"},{"doc":"wisp/wisp_mist","title":"handler","content":"pub fn handler(\n  handler: fn(Request(Connection)) -&gt; Response(Body),\n  secret_key_base: String,\n) -&gt; fn(Request(mist/internal/http.Connection)) -&gt;\n  Response(ResponseData)\n Convert a Wisp request handler into a function that can be run with the Mist\n web server.\n\n # Examples\n\n \n pub fn main() {\n   let secret_key_base = &quot;...&quot;\n   let assert Ok(_) =\n     handle_request\n     |&gt; wisp_mist.handler(secret_key_base)\n     |&gt; mist.new\n     |&gt; mist.port(8000)\n     |&gt; mist.start_http\n   process.sleep_forever()\n }\n \nSynonyms:\nwisp/wisp_mist.handler\nwisp/wisp_mist handler","url":"wisp/wisp_mist.html#handler"},{"doc":"wisp/wisp_mist","title":"wisp/wisp_mist","content":"","url":"wisp/wisp_mist.html"}]);